import requests

url = 'https://margincalculator.angelbroking.com/OpenAPI_File/files/OpenAPIScripMaster.json'
response = requests.get(url)
data = response.json()
result_list = []

class StockCode:

    def getStockCode(symbol):
        for x in data:
            if x['symbol'] == symbol:
                return x['token']
    
    def getStockCodeFormat(symbol_list):
        for sym in range(len(symbol_list)):
            for y in data:
                if y['symbol'] == symbol_list[sym]:
                    result_list.append('nse_cm|' + y['token'])
                    result_list.append('&')
        result_list.pop(-1)
        return ''.join(result_list)




from setuptools import setup

setup(
    name='symcodelib',
    version='0.1',
    description='This library is built to get stock codes in a format required while using SmartApi websocket',
    author='Abhirath Dubey',
    author_email='abhirathdubey2804@gmail.com',
    packages=['symcodelib'],
    install_requires=['requests']
)